pub trait Clip {
// Required method
fn raycast(&self, ray: &Ray<Vector<f32>>, max_distance: f32) -> Option<f32>;
}Expand description
A source of geometry the camera can clip against.
Implemented for any collision world that can cast a ray and return the
distance to the nearest hit within max_distance. With the collide-mesh
feature this is implemented for [collide_mesh::CollisionWorld].
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".